@@ -76,6 +76,7 @@ class EntityTreeModelTest : public QObject
 
 private Q_SLOTS:
     void initTestCase();
+    void cleanupTestCase();
 
     void testInitialFetch();
     void testCollectionMove_data();
@@ -110,7 +111,7 @@ private:
 
         m_modelSpy = new ModelSpy{model, this};
 
-        const auto serverData = new FakeServerData(model, m_fakeSession, fakeMonitor);
+        const auto serverData = new FakeServerData(model, m_fakeSession, fakeMonitor, this);
         serverData->setCommands(FakeJobResponse::interpret(serverData, serverContent));
 
         // Give the model a chance to populate
@@ -144,6 +145,11 @@ void EntityTreeModelTest::initTestCase()
     qRegisterMetaType<QModelIndex>("QModelIndex");
 }
 
+void EntityTreeModelTest::cleanupTestCase()
+{
+    delete m_fakeSession;
+}
+
 void EntityTreeModelTest::testInitialFetch()
 {
     const auto fakeMonitor = new FakeMonitor(this);
@@ -152,7 +158,7 @@ void EntityTreeModelTest::testInitialFetch()
     fakeMonitor->setCollectionMonitored(Collection::root());
     const auto model = new EntityTreeModel(fakeMonitor, this);
 
-    const auto serverData = new FakeServerData(model, m_fakeSession, fakeMonitor);
+    const auto serverData = new FakeServerData(model, m_fakeSession, fakeMonitor, this);
     serverData->setCommands(FakeJobResponse::interpret(serverData, serverContent1));
 
     m_modelSpy = new ModelSpy(model, this);
