@@ -12,7 +12,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+ * License along with this library.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "testrunner.h"
@@ -47,7 +47,7 @@ void TestRunner::run()
     if (!mProcess->waitForStarted()) {
         qWarning() << mArguments << "failed to start!";
         mExitCode = 255;
-        emit finished();
+        Q_EMIT finished();
     }
 }
 
@@ -65,14 +65,14 @@ void TestRunner::processFinished(int exitCode)
         mExitCode = exitCode;
         qDebug() << exitCode;
     }
-    emit finished();
+    Q_EMIT finished();
 }
 
 void TestRunner::processError(QProcess::ProcessError error)
 {
     qWarning() << mArguments << "exited with an error:" << error;
     mExitCode = 255;
-    emit finished();
+    Q_EMIT finished();
 }
 
 void TestRunner::terminate()
