@@ -187,7 +187,7 @@ public:
      * @see setBatchSize()
      * @since 4.14
      */
-    int batchSize() const;
+    Q_REQUIRED_RESULT int batchSize() const;
 
     /**
      * Set the batch size.
@@ -220,7 +220,7 @@ public:
      * @see setMergeMode()
      * @since 5.1
      */
-    MergeMode mergeMode() const;
+    Q_REQUIRED_RESULT MergeMode mergeMode() const;
 
     /**
      * Set what merge method should be used for next ItemSync run
