@@ -338,7 +338,6 @@ QVariant ItemModel::headerData(int section, Qt::Orientation orientation, int rol
 
 void ItemModel::setCollection(const Collection &collection)
 {
-    qCDebug(AKONADICORE_LOG);
     if (d->collection == collection) {
         return;
     }
@@ -374,7 +373,7 @@ void ItemModel::setCollection(const Collection &collection)
         connect(job, &ItemFetchJob::result, this, [this](KJob *job) { d->listingDone(job); });
     }
 
-    emit collectionChanged(collection);
+    Q_EMIT collectionChanged(collection);
 }
 
 void ItemModel::setFetchScope(const ItemFetchScope &fetchScope)
