@@ -124,7 +124,7 @@ bool AkonadiServer::init()
     const QString defaultCmdPipe = QStringLiteral("Akonadi-Cmd-") % suffix;
     const QString cmdPipe = settings.value(QStringLiteral("Connection/NamedPipe"), defaultCmdPipe).toString();
     if (!mCmdServer->listen(cmdPipe)) {
-        qCCritical(AKONADISERVER_LOG) << "Unable to listen on Named Pipe" << cmdPipe;
+        qCCritical(AKONADISERVER_LOG) << "Unable to listen on Named Pipe" << cmdPipe << ":" << mCmdServer->errorString();
         quit();
         return false;
     }
@@ -132,7 +132,7 @@ bool AkonadiServer::init()
     const QString defaultNtfPipe = QStringLiteral("Akonadi-Ntf-") % suffix;
     const QString ntfPipe = settings.value(QStringLiteral("Connection/NtfNamedPipe"), defaultNtfPipe).toString();
     if (!mNtfServer->listen(ntfPipe)) {
-        qCCritical(AKONADISERVER_LOG) << "Unable to listen on Named Pipe" << ntfPipe;
+        qCCritical(AKONADISERVER_LOG) << "Unable to listen on Named Pipe" << ntfPipe << ":" << mNtfServer->errorString();
         quit();
         return false;
     }
@@ -142,19 +142,22 @@ bool AkonadiServer::init()
     connectionSettings.setValue(QStringLiteral("Notifications/Method"), QStringLiteral("NamedPipe"));
     connectionSettings.setValue(QStringLiteral("Notifications/NamedPipe"), ntfPipe);
 #else
-    const QString socketDir = Utils::preferredSocketDirectory(StandardDirs::saveDir("data"));
-    const QString cmdSocketFile = socketDir % QStringLiteral("/akonadiserver-cmd.socket");
+    const QString cmdSocketName = QStringLiteral("akonadiserver-cmd.socket");
+    const QString ntfSocketName = QStringLiteral("akonadiserver-ntf.socket");
+    const QString socketDir = Utils::preferredSocketDirectory(StandardDirs::saveDir("data"),
+                                                              qMax(cmdSocketName.length(), ntfSocketName.length()));
+    const QString cmdSocketFile = socketDir % QLatin1Char('/') % cmdSocketName;
     QFile::remove(cmdSocketFile);
     if (!mCmdServer->listen(cmdSocketFile)) {
-        qCCritical(AKONADISERVER_LOG) << "Unable to listen on Unix socket" << cmdSocketFile;
+        qCCritical(AKONADISERVER_LOG) << "Unable to listen on Unix socket" << cmdSocketFile << ":" << mCmdServer->errorString();
         quit();
         return false;
     }
 
-    const QString ntfSocketFile = socketDir % QStringLiteral("/akonadiserver-ntf.socket");
+    const QString ntfSocketFile = socketDir % QLatin1Char('/') % ntfSocketName;
     QFile::remove(ntfSocketFile);
     if (!mNtfServer->listen(ntfSocketFile)) {
-        qCCritical(AKONADISERVER_LOG) << "Unable to listen on Unix socket" << ntfSocketFile;
+        qCCritical(AKONADISERVER_LOG) << "Unable to listen on Unix socket" << ntfSocketFile << ":" << mNtfServer->errorString();
         quit();
         return false;
     }
