@@ -26,12 +26,12 @@
 #include "intervalcheck.h"
 #include "search/searchmanager.h"
 #include "akonadi.h"
-#include "handler/search.h"
 #include "notificationmanager.h"
 #include "aggregatedfetchscope.h"
 #include "selectquerybuilder.h"
-#include "handler/fetchhelper.h"
+#include "handler/itemfetchhelper.h"
 #include "connection.h"
+#include "shared/akranges.h"
 
 #include "akonadiserver_debug.h"
 
@@ -158,7 +158,8 @@ void NotificationCollector::collectionChanged(const Collection &collection,
     if (changes.contains(AKONADI_PARAM_ENABLED) || changes.contains(AKONADI_PARAM_REFERENCED)) {
         CollectionStatistics::self()->invalidateCollection(collection);
     }
-    collectionNotification(Protocol::CollectionChangeNotification::Modify, collection, collection.parentId(), -1, resource, changes.toSet());
+    collectionNotification(Protocol::CollectionChangeNotification::Modify, collection, collection.parentId(),
+                           -1, resource, changes | toQSet);
 }
 
 void NotificationCollector::collectionMoved(const Collection &collection,
@@ -556,7 +557,7 @@ void NotificationCollector::completeNotification(const Protocol::ChangeNotificat
                 auto itemFetchScope = fetchScope->toFetchScope();
                 auto tagFetchScope = mgr->tagFetchScope()->toFetchScope();
                 itemFetchScope.setFetch(Protocol::ItemFetchScope::CacheOnly);
-                FetchHelper helper(mConnection, &context, Scope(ids), itemFetchScope, tagFetchScope);
+                ItemFetchHelper helper(mConnection, &context, Scope(ids), itemFetchScope, tagFetchScope);
                 // The Item was just changed, which means the atime was
                 // updated, no need to do it again a couple milliseconds later.
                 helper.disableATimeUpdates();
