@@ -20,13 +20,14 @@
 #include "querybuilder.h"
 #include "akonadiserver_debug.h"
 
-
 #ifndef QUERYBUILDER_UNITTEST
 #include "storage/datastore.h"
 #include "storage/querycache.h"
 #include "storage/storagedebugger.h"
 #endif
 
+#include <shared/akranges.h>
+
 #include <QSqlRecord>
 #include <QSqlError>
 #include <QTime>
@@ -363,8 +364,9 @@ bool QueryBuilder::exec()
     buildQuery(&statement);
 
 #ifndef QUERYBUILDER_UNITTEST
-    if (QueryCache::contains(statement)) {
-        mQuery = QueryCache::query(statement);
+    auto query = QueryCache::query(statement);
+    if (query.has_value()) {
+        mQuery = std::move(*query);
     } else {
         mQuery.clear();
         if (!mQuery.prepare(statement)) {
